@@ -1785,6 +1785,7 @@ public:
     void add_array_item(const int64_t &value);
     void add_array_item(const bool &value);
     void add_array_item(const float &value);
+    void add_array_item(const double &value);
     void add_array_item(const std::string &value);
 
     template <class T>
@@ -2167,6 +2168,7 @@ public:
     void get_array_item(int64_t &value);
     void get_array_item(bool &value);
     void get_array_item(float &value);
+    void get_array_item(double &value);
     void get_array_item(std::string &value);
 
     iterator begin();
@@ -2587,6 +2589,11 @@ void SerializerJson::add_array_item(const float &value)
     _json.append(value);
 }
 
+void SerializerJson::add_array_item(const double &value)
+{
+    _json.append(value);
+}
+
 void SerializerJson::add_array_item(const std::string &value)
 {
     _json.append(value);
@@ -2662,6 +2669,11 @@ void DeserializerJson::get_array_item(float &value)
     value = _json.asFloat();
 }
 
+void DeserializerJson::get_array_item(double &value)
+{
+    value = _json.asDouble();
+}
+
 void DeserializerJson::get_array_item(std::string &value)
 {
     value = _json.asString();
